@@ -5,6 +5,7 @@ using SciMLBase: getobserved
 import ChainRulesCore
 import ChainRulesCore: NoTangent, @non_differentiable, zero_tangent, rrule_via_ad
 using SymbolicIndexingInterface
+using RecursiveArrayTools: AbstractVectorOfArray
 
 function ChainRulesCore.rrule(
         config::ChainRulesCore.RuleConfig{
@@ -137,8 +138,12 @@ function ChainRulesCore.rrule(
         RODESolutionAdjoint
 end
 
-function ChainRulesCore.rrule(::SciMLBase.EnsembleSolution, sim, time, converged)
-    out = EnsembleSolution(sim, time, converged)
+# EnsembleSolution rrule with full support for various gradient types
+# Matches the Zygote extension implementation for consistency
+function ChainRulesCore.rrule(
+        ::Type{EnsembleSolution}, sim, time, converged, stats = nothing
+    )
+    out = EnsembleSolution(sim, time, converged, stats)
     function EnsembleSolution_adjoint(p̄::AbstractArray{T, N}) where {T, N}
         arrarr = [
             [
@@ -146,10 +151,37 @@ function ChainRulesCore.rrule(::SciMLBase.EnsembleSolution, sim, time, converged
                     for j in 1:size(p̄)[end - 1]
                 ] for i in 1:size(p̄)[end]
         ]
-        return (NoTangent(), EnsembleSolution(arrarr, 0.0, true), NoTangent(), NoTangent())
+        return (
+            NoTangent(),
+            EnsembleSolution(arrarr, 0.0, true, stats),
+            NoTangent(),
+            NoTangent(),
+            NoTangent(),
+        )
+    end
+    function EnsembleSolution_adjoint(p̄::AbstractArray{<:AbstractArray, 1})
+        return (
+            NoTangent(),
+            EnsembleSolution(p̄, 0.0, true, stats),
+            NoTangent(),
+            NoTangent(),
+            NoTangent(),
+        )
+    end
+    function EnsembleSolution_adjoint(p̄::AbstractVectorOfArray)
+        return (
+            NoTangent(),
+            EnsembleSolution(p̄, 0.0, true, stats),
+            NoTangent(),
+            NoTangent(),
+            NoTangent(),
+        )
     end
     function EnsembleSolution_adjoint(p̄::EnsembleSolution)
-        return (NoTangent(), p̄, NoTangent(), NoTangent())
+        return (NoTangent(), p̄, NoTangent(), NoTangent(), NoTangent())
+    end
+    function EnsembleSolution_adjoint(p̄::NamedTuple)
+        return (NoTangent(), p̄.u, NoTangent(), NoTangent(), NoTangent())
     end
     return out, EnsembleSolution_adjoint
 end
