@@ -10,12 +10,12 @@ function SciMLBase.numargs(f::Py)
     f2 = hasproperty(f, :py_func) ? f.py_func : f
     # if `f` is a bound method (i.e., `self.f`), `getfullargspec` includes
     # `self` in the `args` list. So, we subtract 1 in that case:
-    pyconvert(Int, length(first(inspect.getfullargspec(f2))) - inspect.ismethod(f2))
+    return pyconvert(Int, length(first(inspect.getfullargspec(f2))) - inspect.ismethod(f2))
 end
 
 function _pyconvert(x::Py)
-    pyisinstance(x, pybuiltins.list) ? _promoting_collect(_pyconvert(x) for x in x) :
-    pyconvert(Any, x)
+    return pyisinstance(x, pybuiltins.list) ? _promoting_collect(_pyconvert(x) for x in x) :
+        pyconvert(Any, x)
 end
 _pyconvert(x::PyList) = _promoting_collect(_pyconvert(x) for x in x)
 _pyconvert(x) = x
@@ -25,7 +25,7 @@ _promoting_collect(x) = _promoting_collect(collect(x))
 function _promoting_collect(x::AbstractArray)
     isconcretetype(eltype(x)) && return x
     T = mapreduce(typeof, promote_type, x)
-    T == eltype(x) ? x : T.(x)
+    return T == eltype(x) ? x : T.(x)
 end
 
 SciMLBase.prepare_initial_state(u0::Union{Py, PyList}) = _pyconvert(u0)
