@@ -54,7 +54,7 @@ every solve call.
 * `kwargs`: The keyword arguments passed on to the solvers.
 """
 struct IntervalNonlinearProblem{isinplace, tType, P, F, K, PT} <:
-       AbstractIntervalNonlinearProblem{nothing, isinplace}
+    AbstractIntervalNonlinearProblem{nothing, isinplace}
     f::F
     tspan::tType
     p::P
@@ -67,14 +67,19 @@ struct IntervalNonlinearProblem{isinplace, tType, P, F, K, PT} <:
             tspan,
             p = NullParameters(),
             problem_type = StandardNonlinearProblem();
-            kwargs...) where {iip}
+            kwargs...
+        ) where {iip}
         warn_paramtype(p)
-        new{iip, typeof(tspan), typeof(p), typeof(f),
-            typeof(kwargs), typeof(problem_type)}(f,
+        new{
+            iip, typeof(tspan), typeof(p), typeof(f),
+            typeof(kwargs), typeof(problem_type),
+        }(
+            f,
             tspan,
             p,
             problem_type,
-            kwargs)
+            kwargs
+        )
     end
 
     """
@@ -85,7 +90,7 @@ struct IntervalNonlinearProblem{isinplace, tType, P, F, K, PT} <:
     This is determined automatically, but not inferred.
     """
     function IntervalNonlinearProblem{iip}(f, tspan, p = NullParameters()) where {iip}
-        IntervalNonlinearProblem{iip}(IntervalNonlinearFunction{iip}(f), tspan, p)
+        return IntervalNonlinearProblem{iip}(IntervalNonlinearFunction{iip}(f), tspan, p)
     end
 end
 
@@ -95,13 +100,15 @@ $(SIGNATURES)
 Define a nonlinear problem using an instance of
 [`IntervalNonlinearFunction`](@ref IntervalNonlinearFunction).
 """
-function IntervalNonlinearProblem(f::AbstractIntervalNonlinearFunction, tspan,
-        p = NullParameters(); kwargs...)
-    IntervalNonlinearProblem{isinplace(f)}(f, tspan, p; kwargs...)
+function IntervalNonlinearProblem(
+        f::AbstractIntervalNonlinearFunction, tspan,
+        p = NullParameters(); kwargs...
+    )
+    return IntervalNonlinearProblem{isinplace(f)}(f, tspan, p; kwargs...)
 end
 
 function IntervalNonlinearProblem(f, tspan, p = NullParameters(); kwargs...)
-    IntervalNonlinearProblem(IntervalNonlinearFunction(f), tspan, p; kwargs...)
+    return IntervalNonlinearProblem(IntervalNonlinearFunction(f), tspan, p; kwargs...)
 end
 
 @doc doc"""
@@ -155,7 +162,7 @@ For specifying Jacobians and mass matrices, see the
 * `kwargs`: The keyword arguments passed on to the solvers.
 """
 mutable struct NonlinearProblem{uType, isinplace, P, F, K, PT, LB, UB} <:
-               AbstractNonlinearProblem{uType, isinplace}
+    AbstractNonlinearProblem{uType, isinplace}
     f::F
     u0::uType
     p::P
@@ -163,24 +170,30 @@ mutable struct NonlinearProblem{uType, isinplace, P, F, K, PT, LB, UB} <:
     lb::LB
     ub::UB
     kwargs::K
-    @add_kwonly function NonlinearProblem{iip}(f::AbstractNonlinearFunction{iip}, u0,
+    @add_kwonly function NonlinearProblem{iip}(
+            f::AbstractNonlinearFunction{iip}, u0,
             p = NullParameters(),
             problem_type = StandardNonlinearProblem();
             lb = nothing,
             ub = nothing,
-            kwargs...) where {iip}
+            kwargs...
+        ) where {iip}
         if haskey(kwargs, :p)
             error("`p` specified as a keyword argument `p = $(kwargs[:p])` to `NonlinearProblem`. This is not supported.")
         end
         warn_paramtype(p)
-        new{typeof(u0), iip, typeof(p), typeof(f),
-            typeof(kwargs), typeof(problem_type), typeof(lb), typeof(ub)}(f,
+        new{
+            typeof(u0), iip, typeof(p), typeof(f),
+            typeof(kwargs), typeof(problem_type), typeof(lb), typeof(ub),
+        }(
+            f,
             u0,
             p,
             problem_type,
             lb,
             ub,
-            kwargs)
+            kwargs
+        )
     end
 
     """
@@ -191,7 +204,7 @@ mutable struct NonlinearProblem{uType, isinplace, P, F, K, PT, LB, UB} <:
     This is determined automatically, but not inferred.
     """
     function NonlinearProblem{iip}(f, u0, p = NullParameters(); kwargs...) where {iip}
-        NonlinearProblem{iip}(NonlinearFunction{iip}(f), u0, p; kwargs...)
+        return NonlinearProblem{iip}(NonlinearFunction{iip}(f), u0, p; kwargs...)
     end
 end
 
@@ -202,11 +215,11 @@ Define a nonlinear problem using an instance of
 [`AbstractNonlinearFunction`](@ref AbstractNonlinearFunction).
 """
 function NonlinearProblem(f::AbstractNonlinearFunction, u0, p = NullParameters(); kwargs...)
-    NonlinearProblem{isinplace(f)}(f, u0, p; kwargs...)
+    return NonlinearProblem{isinplace(f)}(f, u0, p; kwargs...)
 end
 
 function NonlinearProblem(f, u0, p = NullParameters(); kwargs...)
-    NonlinearProblem(NonlinearFunction(f), u0, p; kwargs...)
+    return NonlinearProblem(NonlinearFunction(f), u0, p; kwargs...)
 end
 
 """
@@ -215,7 +228,7 @@ $(SIGNATURES)
 Define a `NonlinearProblem` problem from `SteadyStateProblem`
 """
 function NonlinearProblem(prob::AbstractNonlinearProblem)
-    NonlinearProblem{isinplace(prob)}(prob.f, prob.u0, prob.p)
+    return NonlinearProblem{isinplace(prob)}(prob.f, prob.u0, prob.p)
 end
 
 """
@@ -227,11 +240,11 @@ this is interpreted in the form of the steady state problem, i.e.
 find the ODE's solution at time ``t = \\infty``.
 """
 function NonlinearProblem(f::AbstractODEFunction, u0, p = NullParameters(); kwargs...)
-    NonlinearProblem{isinplace(f)}(f, u0, p; kwargs...)
+    return NonlinearProblem{isinplace(f)}(f, u0, p; kwargs...)
 end
 
 function ConstructionBase.constructorof(::Type{P}) where {P <: NonlinearProblem}
-    function ctor(f, u0, p, pt, lb, ub, kw)
+    return function ctor(f, u0, p, pt, lb, ub, kw)
         if f isa AbstractNonlinearFunction
             iip = isinplace(f)
         else
@@ -249,17 +262,17 @@ this is interpreted in the form of the steady state problem, i.e.
 find the ODE's solution at time ``t = ∞``
 """
 function NonlinearProblem(prob::AbstractODEProblem)
-    NonlinearProblem{isinplace(prob)}(prob.f, prob.u0, prob.p; prob.kwargs...)
+    return NonlinearProblem{isinplace(prob)}(prob.f, prob.u0, prob.p; prob.kwargs...)
 end
 
 function Base.setproperty!(prob::NonlinearProblem, s::Symbol, v)
     @warn "Mutation of NonlinearProblem detected. SciMLBase v2.0 has made NonlinearProblem temporarily mutable in order to allow for interfacing with EnzymeRules due to a current limitation in the rule system. This change is only intended to be temporary and NonlinearProblem will return to being a struct in a later non-breaking release. Do not rely on this behavior, use with caution."
-    Base.setfield!(prob, s, v)
+    return Base.setfield!(prob, s, v)
 end
 
 function Base.setproperty!(prob::NonlinearProblem, s::Symbol, v, order::Symbol)
     @warn "Mutation of NonlinearProblem detected. SciMLBase v2.0 has made NonlinearProblem temporarily mutable in order to allow for interfacing with EnzymeRules due to a current limitation in the rule system. This change is only intended to be temporary and NonlinearProblem will return to being a struct in a later non-breaking release. Do not rely on this behavior, use with caution."
-    Base.setfield!(prob, s, v, order)
+    return Base.setfield!(prob, s, v, order)
 end
 
 @doc doc"""
@@ -309,7 +322,7 @@ For specifying Jacobians and mass matrices, see the
 * `kwargs`: The keyword arguments passed on to the solvers.
 """
 struct NonlinearLeastSquaresProblem{uType, isinplace, P, F, K, LB, UB} <:
-       AbstractNonlinearProblem{uType, isinplace}
+    AbstractNonlinearProblem{uType, isinplace}
     f::F
     u0::uType
     p::P
@@ -319,14 +332,18 @@ struct NonlinearLeastSquaresProblem{uType, isinplace, P, F, K, LB, UB} <:
 
     @add_kwonly function NonlinearLeastSquaresProblem{iip}(
             f::AbstractNonlinearFunction{
-                iip}, u0,
+                iip,
+            }, u0,
             p = NullParameters();
             lb = nothing,
             ub = nothing,
-            kwargs...) where {iip}
+            kwargs...
+        ) where {iip}
         warn_paramtype(p)
-        return new{typeof(u0), iip, typeof(p), typeof(f), typeof(kwargs),
-                   typeof(lb), typeof(ub)}(f, u0, p, lb, ub, kwargs)
+        return new{
+            typeof(u0), iip, typeof(p), typeof(f), typeof(kwargs),
+            typeof(lb), typeof(ub),
+        }(f, u0, p, lb, ub, kwargs)
     end
 
     function NonlinearLeastSquaresProblem{iip}(f, u0, p = NullParameters()) where {iip}
@@ -340,8 +357,10 @@ $(SIGNATURES)
 Define a nonlinear least squares problem using an instance of
 [`AbstractNonlinearFunction`](@ref AbstractNonlinearFunction).
 """
-function NonlinearLeastSquaresProblem(f::AbstractNonlinearFunction, u0,
-        p = NullParameters(); kwargs...)
+function NonlinearLeastSquaresProblem(
+        f::AbstractNonlinearFunction, u0,
+        p = NullParameters(); kwargs...
+    )
     return NonlinearLeastSquaresProblem{isinplace(f)}(f, u0, p; kwargs...)
 end
 
@@ -350,7 +369,7 @@ function NonlinearLeastSquaresProblem(f, u0, p = NullParameters(); kwargs...)
 end
 
 function ConstructionBase.constructorof(::Type{P}) where {P <: NonlinearLeastSquaresProblem}
-    function ctor(f, u0, p, lb, ub, kw)
+    return function ctor(f, u0, p, lb, ub, kw)
         if f isa AbstractNonlinearFunction
             iip = isinplace(f)
         else
@@ -502,9 +521,11 @@ Note that this example aliases the parameters together for a memory-reduced repr
 * `probs`: the collection of problems to solve
 * `explictfuns!`: the explicit functions for mutating the parameter set
 """
-mutable struct SCCNonlinearProblem{uType, iip, P, E, F <: NonlinearFunction{iip},
-    Par, Palias <: Union{Val{true}, Val{false}}} <:
-               AbstractNonlinearProblem{uType, iip}
+mutable struct SCCNonlinearProblem{
+        uType, iip, P, E, F <: NonlinearFunction{iip},
+        Par, Palias <: Union{Val{true}, Val{false}},
+    } <:
+    AbstractNonlinearProblem{uType, iip}
     probs::P
     explicitfuns!::E
     # NonlinearFunction with `f = Returns(nothing)`
@@ -512,30 +533,48 @@ mutable struct SCCNonlinearProblem{uType, iip, P, E, F <: NonlinearFunction{iip}
     p::Par
     parameters_alias::Palias
 
-    function SCCNonlinearProblem{P, E, F, Par}(probs::P, funs::E, f::F, pobj::Par,
-            alias::Palias) where {P, E, F <: NonlinearFunction, Par, Palias}
+    function SCCNonlinearProblem{P, E, F, Par}(
+            probs::P, funs::E, f::F, pobj::Par,
+            alias::Palias
+        ) where {P, E, F <: NonlinearFunction, Par, Palias}
         init = state_values(first(probs))
+        has_no_u0 = init === nothing
+        if has_no_u0
+            # In this case, all of `probs` are `LinearProblem`
+            @assert first(probs) isa LinearProblem
+            init = first(probs).A
+        end
         if ArrayInterface.ismutable(init)
             init = similar(init, 0)
         else
             init = StaticArraysCore.similar_type(init, StaticArraysCore.Size(0))()
         end
-        u0 = mapreduce(
-            state_values, vcat, probs; init = init)
-        uType = typeof(u0)
-        new{uType, false, P, E, F, Par, Palias}(probs, funs, f, pobj, alias)
+        if has_no_u0
+            uType = Nothing
+        else
+            u0 = mapreduce(
+                state_values, vcat, probs; init = init
+            )
+            uType = typeof(u0)
+        end
+        return new{uType, false, P, E, F, Par, Palias}(probs, funs, f, pobj, alias)
     end
 end
 
-function SCCNonlinearProblem(probs, explicitfuns!, parameter_object = nothing,
-        parameters_alias::Union{Bool, Val{true}, Val{false}} = Val(false); kwargs...)
+function SCCNonlinearProblem(
+        probs, explicitfuns!, parameter_object = nothing,
+        parameters_alias::Union{Bool, Val{true}, Val{false}} = Val(false); kwargs...
+    )
     f = NonlinearFunction{false}(Returns(nothing); kwargs...)
     if parameters_alias isa Bool
         parameters_alias = Val(parameters_alias)
     end
-    return SCCNonlinearProblem{typeof(probs), typeof(explicitfuns!),
-        typeof(f), typeof(parameter_object)}(
-        probs, explicitfuns!, f, parameter_object, parameters_alias)
+    return SCCNonlinearProblem{
+        typeof(probs), typeof(explicitfuns!),
+        typeof(f), typeof(parameter_object),
+    }(
+        probs, explicitfuns!, f, parameter_object, parameters_alias
+    )
 end
 
 function Base.getproperty(prob::SCCNonlinearProblem, name::Symbol)
@@ -548,10 +587,13 @@ function Base.getproperty(prob::SCCNonlinearProblem, name::Symbol)
 end
 
 function SymbolicIndexingInterface.symbolic_container(prob::SCCNonlinearProblem)
-    prob.f
+    return prob.f
 end
 function SymbolicIndexingInterface.parameter_values(prob::SCCNonlinearProblem)
-    prob.p
+    return prob.p
+end
+function SymbolicIndexingInterface.state_values(prob::SCCNonlinearProblem{Nothing})
+    return nothing
 end
 function SymbolicIndexingInterface.state_values(prob::SCCNonlinearProblem)
     init = state_values(first(prob.probs))
@@ -560,7 +602,7 @@ function SymbolicIndexingInterface.state_values(prob::SCCNonlinearProblem)
     else
         init = StaticArraysCore.similar_type(init, StaticArraysCore.Size(0))()
     end
-    mapreduce(state_values, vcat, prob.probs; init)
+    return mapreduce(state_values, vcat, prob.probs; init)
 end
 
 function SymbolicIndexingInterface.set_state!(prob::SCCNonlinearProblem, val, idx)
@@ -581,6 +623,7 @@ function SymbolicIndexingInterface.set_parameter!(prob::SCCNonlinearProblem, val
         is_parameter(scc, idx) || continue
         set_parameter!(scc, val, idx)
     end
+    return
 end
 
 @doc doc"""
@@ -604,8 +647,9 @@ struct NonlinearAliasSpecifier <: AbstractAliasSpecifier
     alias_u0::Union{Bool, Nothing}
 
     function NonlinearAliasSpecifier(;
-            alias_p = nothing, alias_f = nothing, alias_u0 = nothing, alias = nothing)
-        if isnothing(alias)
+            alias_p = nothing, alias_f = nothing, alias_u0 = nothing, alias = nothing
+        )
+        return if isnothing(alias)
             new(alias_p, alias_f, alias_u0)
         elseif alias
             new(true, true, true)
@@ -616,7 +660,7 @@ struct NonlinearAliasSpecifier <: AbstractAliasSpecifier
 end
 
 struct ImmutableNonlinearProblem{uType, iip, P, F, K, PT} <:
-       AbstractNonlinearProblem{uType, iip}
+    AbstractNonlinearProblem{uType, iip}
     f::F
     u0::uType
     p::P
@@ -625,15 +669,18 @@ struct ImmutableNonlinearProblem{uType, iip, P, F, K, PT} <:
 
     SciMLBase.@add_kwonly function ImmutableNonlinearProblem{iip}(
             f::AbstractNonlinearFunction{iip}, u0, p = NullParameters(),
-            problem_type = StandardNonlinearProblem(); kwargs...) where {iip}
+            problem_type = StandardNonlinearProblem(); kwargs...
+        ) where {iip}
         if haskey(kwargs, :p)
             error("`p` specified as a keyword argument `p = $(kwargs[:p])` to \
                    `NonlinearProblem`. This is not supported.")
         end
         SciMLBase.warn_paramtype(p)
         return new{
-            typeof(u0), iip, typeof(p), typeof(f), typeof(kwargs), typeof(problem_type)}(
-            f, u0, p, problem_type, kwargs)
+            typeof(u0), iip, typeof(p), typeof(f), typeof(kwargs), typeof(problem_type),
+        }(
+            f, u0, p, problem_type, kwargs
+        )
     end
 
     """
@@ -642,7 +689,8 @@ struct ImmutableNonlinearProblem{uType, iip, P, F, K, PT} <:
     This is determined automatically, but not inferred.
     """
     function ImmutableNonlinearProblem{iip}(
-            f, u0, p = NullParameters(); kwargs...) where {iip}
+            f, u0, p = NullParameters(); kwargs...
+        ) where {iip}
         return ImmutableNonlinearProblem{iip}(NonlinearFunction{iip}(f), u0, p; kwargs...)
     end
 end
@@ -651,7 +699,8 @@ end
 Define a nonlinear problem using an instance of [`AbstractNonlinearFunction`](@ref).
 """
 function ImmutableNonlinearProblem(
-        f::AbstractNonlinearFunction, u0, p = NullParameters(); kwargs...)
+        f::AbstractNonlinearFunction, u0, p = NullParameters(); kwargs...
+    )
     return ImmutableNonlinearProblem{SciMLBase.isinplace(f)}(f, u0, p; kwargs...)
 end
 
@@ -667,7 +716,9 @@ function ImmutableNonlinearProblem(prob::AbstractNonlinearProblem)
 end
 
 function Base.convert(
-        ::Type{ImmutableNonlinearProblem}, prob::T) where {T <: NonlinearProblem}
+        ::Type{ImmutableNonlinearProblem}, prob::T
+    ) where {T <: NonlinearProblem}
     return ImmutableNonlinearProblem{SciMLBase.isinplace(prob)}(
-        prob.f, prob.u0, prob.p, prob.problem_type; prob.kwargs...)
+        prob.f, prob.u0, prob.p, prob.problem_type; prob.kwargs...
+    )
 end
